local L = LibStub("AceLocale-3.0"):GetLocale("HitsMode5")
local deletefilter = nil


HitsMode5.options = {
	name = "HitsMode5         r|cff20ff20"..HitsMode5.MINOR_VERSION.."|r",
	handler = HitsMode5,
	type = "group",
	args = {		
	
	
--[[ General ]]----------------------------------------------------------------------------------------------------------------------

		general = {
			type = "group",
			name = L["General Options"],
			order = 1,
			args = {
			
				enable = {
					type = "toggle",
					name = L["Enable HitsMode5"],
					desc = L["Enables or disables HitsMode5 entirely. When disabled, HitsMode5 will not respond to any combat log events. You will still be able to enable HitsMode5 and replay the combat log to see what happened."],
					get = function() return HitsMode5.db.enabled or true end,
					set = function(self, val) HitsMode5.db.enabled = val end,
					order = 1,
				}, -- enable
				
				replayDuration = {
					type = "range",
					name = L["Combat log retention time"],
					desc = L["Determines how long your WoW client will retain combat log data (in seconds). This affects HitsMode5's ability to replay the combat log. Longer retention times will cause your client to use more of your RAM, but will allow you to evaluate a longer period of combat after it has happened. The default setting is 5 minutes (300 seconds). Note that this is a WoW setting, not a HitsMode5 setting. This WoW setting is normally hidden from users.\n\nWoW currently imposes a limit of 315 seconds for this value."],
					min = 0,
					max = 315,
					step = 1,
					get = function() return CombatLogGetRetentionTime() end,
					set = function(self, val) CombatLogSetRetentionTime(val) end,
				},
				
				replayLinesPerFrame = {
					type = "range",
					name = L["Replay lines per frame"],
					desc = L["When HitsMode5 replays your combat log, it replays a certain number of lines per frame. This prevents your client from locking up for an extended period of time while the combat log is replayed. You may wish to adjust this setting to a higher number if you have a very fast computer, need to replay a long combat log (particularly in a raid), and don't mind a little lag while it happens. The default Blizzard Combat Log replays one line per frame."],
					min = 1,
					max = 100,
					step = 1,
					get = function() return HitsMode5.db.replayLinesPerFrame or 10 end,
					set = function(self, val) HitsMode5.db.replayLinesPerFrame = val end,
				},
			
			}
		},
	
		
--[[ Filters ]]----------------------------------------------------------------------------------------------------------------------

		filters = {
			type = "group",
			name = L["Filters"],
			order = 2,
			args = {

				create = {
					type = "input",
					name = L["Create filter"],
					desc = L["Enter the name for the new filter."],
					set = function(self, val) if val and val ~= "" then HitsMode5:CreateFilter(val) end end,
					order = 1,
				},

				delete = {
					type = "select",
					name = L["Delete filter"],
					desc = L["Choose the filter to be deleted."],
					values =	function()
						local filters = {}
						for k, v in ipairs(HitsMode5:GetFilters()) do
							filters[v.db.name] = v.db.name
						end
						return filters
					end,
					get = function() return deletefilter end,
					set = function(self, val) deletefilter = val end,
					order = 2,
				},
				
				deleteexecute = {
					type = "execute",
					name = L["Delete filter"],
					desc = L["Deletes the chosen filter."],
					confirm = true,
					confirmText = L["Are you sure you want to delete this filter?"],
					func = function(self) if deletefilter then HitsMode5:DeleteFilter(deletefilter) end end,
					order = 3,
				},

			},
		}, -- filters

		
--[[ Help ]]-------------------------------------------------------------------------------------------------------------------------

		help = {
			type = "group",
			name = L["Help"],
			order = 999,
			
			args = {
				help = {
					type = "execute",
					name = L["Help with HitsMode5"],
					func = function()
						InterfaceOptionsFrame:Hide()
						ToggleHelpFrame()
						HitsMode5:ScheduleTimer("CheckHelpLoaded", 0.2)
					end,
					order = 999
				}
			} -- args
		}, -- help
		
	} -- args
} -- options

